# -*- coding: UTF-8 -*-

import logging
import logging.handlers
import logging.config
import sys, os
import ConfigParser

class Logger(object):
    dests = []
    location = None

    def __init__(self, location=None):
        if not Logger.location:
            Logger.location = location
            try:
                if Logger.location == "cs":
                    logging.config.fileConfig("/opt/nes/logging.properties")
                else:
                    logging.config.fileConfig("/linuxcash/cash/exchangesystems/nes/logging.properties")
            except Exception as e:
                print(u'logger configure error: `%s`' % e)
                logging.basicConfig(level=logging.INFO, format='%(asctime)s %(levelname)-8s %(message)s %(module)5s(%(lineno)s)')

    def getLogDirectory(self, exchangers=True):
        if Logger.location == "cs":
            configPath = "/opt"
        else:
            configPath = "/linuxcash/cash/exchangesystems"
        if exchangers:
            configPath += "/exchangers/config/%s/exchangers.ini" % Logger.location
        else:
            configPath += "/nes/config/nes_load.ini"
        config = ConfigParser.RawConfigParser()
        if not config.read(configPath):
            print(u"Configuration file '%s' not found." % configPath)
            exit(1)
        if exchangers:
            parentDir = config.get('main', 'logDirectory')
        else:
            parentDir = config.get('MAIN', 'logDirectory')
        if not os.path.exists(parentDir):
            os.makedirs(parentDir)
        return parentDir

    def getLoggerUpload(self, name, dest=None):
        if dest is not None:
            dest = 'dictLoad%s' % dest
        return self.getLoggerExchangers('dictLoad' + name, dest)

    def getLoggerUnload(self, name, dest=None):
        if dest is not None:
            dest = 'saleUnload%s' % dest
        return self.getLoggerExchangers('saleUnload' + name, dest)

    def getLoggerExchangers(self, name, dest=None):
        return self.__getLogger(True, name, dest)

    def getLoggerNes(self, name, dest=None):
        if dest is not None:
            dest = 'nesUpload%s' % dest
        return self.__getLogger(False, 'nesUpload' + name, dest)

    def __getLogger(self, exchangers, name, dest):
        if dest is None:
            dest = name
        logger = logging.getLogger(name)
        if dest not in Logger.dests:
            logger = self.__configureLogger(logger, '%s/%s.log' % (self.getLogDirectory(exchangers), dest))
            Logger.dests.append(dest)
        return logger

    def __configureLogger(self, logger, logPath):
        if len(logger.handlers):
            handler = logger.handlers[0]
            handler.close()
            handler.baseFilename = logPath
            handler._open()
        else:
            handler = logging.handlers.WatchedFileHandler(logPath, "a", None, False)
            handler.setFormatter(logging.Formatter('%(asctime)s %(levelname)-8s %(message)s %(module)5s(%(lineno)s)'))
            logger.addHandler(handler)
        return logger
